# API Reference

## Parsing

::: parsantic.parse

::: parsantic.parse_stream

::: parsantic.parse_debug

## Extraction

::: parsantic.extract

::: parsantic.extract_iter

::: parsantic.extract_aiter

## Coercion

::: parsantic.coerce

::: parsantic.coerce_debug

## Update

::: parsantic.update

::: parsantic.aupdate

## JSON Patch

::: parsantic.apply_patch

::: parsantic.apply_patch_and_validate

::: parsantic.normalize_patches

## Types

::: parsantic.ParseOptions

::: parsantic.CoerceOptions

::: parsantic.RetryPolicy

::: parsantic.JsonPatchOp

::: parsantic.UpdateResult

::: parsantic.extract.Document

::: parsantic.extract.options.ExtractOptions

::: parsantic.extract.SourceRef

::: parsantic.extract.options.MediaOptions
